/*

Copyright (C) 2002-2003, Jeffrey D. Argast.

The authors make NO WARRANTY or representation, either express or implied,
with respect to this software, its quality, accuracy, merchantability, or
fitness for a particular purpose.  This software is provided "AS IS", and you,
its user, assume the entire risk as to its quality and accuracy.

Permission is hereby granted to use, copy, modify, and distribute this
software or portions thereof for any purpose, without fee, subject to these
conditions:

(1) If any part of the source code is distributed, then this
statement must be included, with this copyright and no-warranty notice
unaltered.

(2) Permission for use of this software is granted only if the user accepts
full responsibility for any undesirable consequences; the authors accept
NO LIABILITY for damages of any kind.

*/

#import "JobsView.h"
#import "JobsController.h"

@implementation JobsView

- (NSMenu *)menuForEvent:(NSEvent *)theEvent
{
	[[self window] makeFirstResponder:self];

    NSPoint clickPoint = [theEvent locationInWindow];
    
    clickPoint = [self convertPoint:clickPoint fromView:nil];
    
    int rowIdx = [self rowAtPoint:clickPoint];

	if ( rowIdx >= 0 )
	{
		[self selectRow:rowIdx byExtendingSelection:NO];
			
		return [super menuForEvent:theEvent];
	}
	
	return nil;
}

- (BOOL) validateMenuItem:(NSMenuItem*)menuItem
{
	JobsController* controller = [self delegate];
	
	SEL selector = [menuItem action];
   
	if ( selector == @selector(editJob:) )
	{
		return [controller canEdit];
	}
	
	if ( selector == @selector(describeJob:) )
	{
		return [controller canDescribe];
	}
	
	if ( selector == @selector(deleteJob:) )
	{
		return [controller canDelete];
	}
	
	return YES;
}

- (IBAction) editJob:(id)sender
{
	id <JobProtocol> controller = [self delegate];
	
	[controller doEdit];
}

- (IBAction) describeJob:(id)sender
{
	id <JobProtocol> controller = [self delegate];
	
	[controller doDescribe];
}

- (IBAction) deleteJob:(id)sender
{
	id <JobProtocol> controller = [self delegate];
	
	[controller doDelete];
}


@end
